==> oktan-nautika-inti-gath-0.1.3-571b83.tar: src/Wp/Plugin/GathImageUpload.php <==
<?php
namespace Inti\Gath\Wp\Plugin;

use Inti\Gath\Wp\ImageManager;
use Inti\WordPress\Plugin\PluginInterface;

/**
 * Class GathImageUpload
 *
 * @package Inti\Gath\Wp\Plugin
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-gath
 */
final class GathImageUpload implements PluginInterface
{
    /** @var ImageManager */
    private $manager;

    /**
     * Konstruktor.
     *
     * @param ImageManager $manager
     */
    public function __construct(ImageManager $manager)
    {
        $this->manager = $manager;
    }

    /**
     * @inheritDoc
     */
    public function init()
    {
        add_action('init', [$this, 'add_route']);
        add_filter('query_vars', [$this, 'query_vars']);
        add_filter('redirect_canonical', [$this, 'ignore_trailing_slash']);
        add_action('template_redirect', [$this, 'handle_upload']);
        add_filter('intermediate_image_sizes_advanced', [$this, 'prevent_thumbnail_generation']);
    }

    public function add_route()
    {
        add_rewrite_rule('gath-uploads/(.+)/?$', 'index.php?gath_path=$matches[1]', 'top');
    }

    public function ignore_trailing_slash($redirect)
    {
        global $wp_query;

        if (!empty($wp_query->query_vars['gath_path'])) {
            return false;
        }

        return $redirect;
    }

    public function query_vars(array $query_vars): array
    {
        $query_vars[] = 'gath_path';
        return $query_vars;
    }

    public function handle_upload()
    {
        global $wp_query;

        if (!empty($wp_query->query_vars['gath_path'] ?? '') && $_SERVER['REQUEST_METHOD'] === 'POST') {
            $image = file_get_contents('php://input');
            $this->manager->uploadImage($wp_query->query_vars['gath_path'], $image);
            exit;
        }
    }

    public function remove_slash_from_charlist(array $charlist): array
    {
        if (($index = array_search('/', $charlist)) !== false) {
            unset($charlist[$index]);
        }

        return $charlist;
    }

    public function preserve_dirname_in_filename(string $filename): string
    {
        return $filename;
    }

    /**
     * @return array
     */
    public function prevent_thumbnail_generation()
    {
        return [];
    }
}

==> oktan-nautika-inti-gath-0.1.4-89103a.tar: src/Wp/Plugin/GathImageUpload.php <==
<?php
namespace Inti\Gath\Wp\Plugin;

use Inti\Gath\Wp\ImageManager;
use Inti\Wp\Plugin\PluginInterface;

/**
 * Class GathImageUpload
 *
 * @package Inti\Gath\Wp\Plugin
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-gath
 */
final class GathImageUpload implements PluginInterface
{
    /** @var ImageManager */
    private $manager;

    /**
     * Konstruktor.
     *
     * @param ImageManager $manager
     */
    public function __construct(ImageManager $manager)
    {
        $this->manager = $manager;
    }

    public function run(?array $options = null): void
    {
        add_action('init', [$this, 'add_route']);
        add_filter('query_vars', [$this, 'query_vars']);
        add_filter('redirect_canonical', [$this, 'ignore_trailing_slash']);
        add_action('template_redirect', [$this, 'handle_upload']);
        add_filter('intermediate_image_sizes_advanced', [$this, 'prevent_thumbnail_generation']);
    }

    public function add_route()
    {
        add_rewrite_rule('gath-uploads/(.+)/?$', 'index.php?gath_path=$matches[1]', 'top');
    }

    public function ignore_trailing_slash($redirect)
    {
        global $wp_query;

        if (!empty($wp_query->query_vars['gath_path'])) {
            return false;
        }

        return $redirect;
    }

    public function query_vars(array $query_vars): array
    {
        $query_vars[] = 'gath_path';
        return $query_vars;
    }

    public function handle_upload()
    {
        global $wp_query;

        if (!empty($wp_query->query_vars['gath_path'] ?? '') && $_SERVER['REQUEST_METHOD'] === 'POST') {
            $image = file_get_contents('php://input');
            $this->manager->uploadImage($wp_query->query_vars['gath_path'], $image);
            exit;
        }
    }

    public function remove_slash_from_charlist(array $charlist): array
    {
        if (($index = array_search('/', $charlist)) !== false) {
            unset($charlist[$index]);
        }

        return $charlist;
    }

    public function preserve_dirname_in_filename(string $filename): string
    {
        return $filename;
    }

    /**
     * @return array
     */
    public function prevent_thumbnail_generation(): array
    {
        return [];
    }
}
